@@ -4,7 +4,7 @@ use warnings;
 
 package Mxpress::PDF {
 	BEGIN {
-		our $VERSION = '0.15';
+		our $VERSION = '0.16';
 		our $AUTHORITY = 'cpan:LNATION';
 	};
 	use Zydeco;
@@ -826,10 +826,9 @@ package Mxpress::PDF {
 				$self->set_attrs(%args);
 				my $placeholder = $self->toc_placeholder;
 				my ($x, $y, $w, $h) = $self->set_position(@{$placeholder->{position}});
-				# todo better
 				$args{page_offset} = 0;
 				my $one_toc_link = $self->outlines->[0]->font->size + $self->toc_line_offset/mm;
-				my $total_height = ($self->count * $one_toc_link) - ($h + ($self->file->page->h * $self->file->page->columns - 1));
+				my $total_height = ($self->count * $one_toc_link) - ($h + ($self->file->page->h * ($self->file->page->columns - 1)));
 				while ($total_height > 0) {
 					$args{page_offset}++;
 					$self->file->add_page(num => $placeholder->{page}->num + $args{page_offset});
@@ -977,6 +976,7 @@ package Mxpress::PDF {
 				$annotate->{Subtype} = PDFName('Widget');
 				$annotate->rect(@pos);
 				$annotate->{FT} = PDFName('Tx');
+				$annotate->{T} = PDFStr($text);
 				$form->bbox(@pos);
 				return $file;
 			}
@@ -1026,7 +1026,7 @@ Mxpress::PDF - PDF
 
 =head1 VERSION
 
-Version 0.15
+Version 0.16
 
 =cut
 
